==> chart-0.2.5.tar.gz: example/web/chart.dart <==
library chart;

import 'dart:html';
import 'dart:math' as math;
import 'package:intl/intl.dart';
import 'package:chart/chart.dart';


void main() {
  
  
  Map<double,String> scaleLabel = new Map<double, String>();
  scaleLabel[20.0] = 'Tsunami';
  scaleLabel[20.5] = 'Sinnflut';

  scaleLabel[21.5] = 'Regen';
  scaleLabel[22.0] = 'Sonne';
  
  Line chart = new Line({
    'labels' : ["January","February","March","April","May","June","July","August"],
    'datasets' : [
                {
                  'fillColor' : "rgba(220,220,220,0.5)",
                  'strokeColor' : "rgba(0,0,0,1)",
                  'pointColor' : "rgba(220,220,220,1)",
                  'pointStrokeColor' : "#fff",
                  'data' : [null,21,20.92221,21,23,20,21.4333,21]
                },
                {
                  'fillColor' : "rgba(151,187,205,0.5)",
                  'strokeColor' : "rgba(151,187,205,1)",
                  'pointColor' : "rgba(151,187,205,1)",
                  'pointStrokeColor' : "#fff",
                  'data' : [18,20,16,24,24,24,20,21]
                }
    ]
  }, {
    'scaleLabel' : scaleLabel,
    'scaleOverride' : false, 
    'scaleSteps' : 4, 
    'scaleStepWidth' : 0.5, 
    'scaleStartValue' : 20.0,
    'bezierCurve' : true, 
    'animation' : false
    });
    
  
  Line chart2 = new Line({
    'labels' : ["1","2","3","4","5","6"],
    'datasets' : [
                {
                  'fillColor' : "rgba(123,244,220,0.5)",
                  'strokeColor' : "rgba(220,220,220,1)",
                  'pointColor' : "rgba(220,220,220,1)",
                  'pointStrokeColor' : "#fff",
                  'data' : [
                            [null,20,16],
                            null,
                            [null,10,null],
                            24,
                            [null, null, null, null],
                            [null,17,null,25,null,20,14,null,23,25,40,20,null]
                  ]
                }
    ]

  }, {
    'animationEasing': 'easeOutElastic',
    'animation' : false,
    'bezierCurve' : true, 
    }
  );
  
  Bar bar = new Bar({
                      'labels' : ["January","February","March","April","May","June","July"],
                      'datasets' : [
                                  {
                                    'fillColor' : "rgba(220,220,220,0.5)",
                                    'strokeColor' : "rgba(220,220,220,1)",
                                    'data' : [65,59,90,81,56,55,40]
                                  },
                                  {
                                    'fillColor' : "rgba(255,255,255,1)",
                                    'strokeColor' : "rgba(0,0,255,0.5)",
                                    'data' : [28,48,40,19,null,27,100]
                                  }
                                  ]

  }, null);
  
  Bar bar2 = new Bar({
                      'labels' : ["January","February","March","April","May","June","July"],
                      'datasets' : [
                                  {
                                    'fillColor' : "rgba(220,220,220,0.5)",
                                    'strokeColor' : "rgba(220,220,220,1)",
                                    'data' : [55,59,90,59,56,55,60]
                                  }]

  }, null);

  DivElement container = new DivElement();
  container.style.height ='400px';
  container.style.width =  '100%';
  document.body.children.add(container);
  chart.show(container);
  
  DivElement container2 = new DivElement();
  container2.style.height ='400px';
  container2.style.width =  '100%';
  document.body.children.add(container2);
  chart2.show(container2);
  
  DivElement container3 = new DivElement();
  container3.style.height ='400px';
  container3.style.width =  '100%';
  document.body.children.add(container3);
  bar.show(container3);
  
  DivElement container4 = new DivElement();
  container4.style.height ='400px';
  container4.style.width =  '100%';
  document.body.children.add(container4);
  bar2.show(container4);


}

==> chart-0.3.0.tar.gz: example/web/chart.dart <==
library chart;

import 'dart:html';
import 'package:chart/chart.dart';


void main() {
  
  
  Line chart = new Line({
    'labels' : ["January","February","March","April","May","June","July","August"],
    'datasets' : [
                {
                  'fillColor' : "rgba(220,220,220,0.5)",
                  'strokeColor' : "rgba(0,0,0,1)",
                  'pointColor' : "rgba(220,220,220,1)",
                  'pointStrokeColor' : "#fff",
                  'pointDot' : false,
                  'data' : [4,5,2,5,6,3,7,3]
                },
                {
                  'fillColor' : "rgba(151,187,205,0.5)",
                  'strokeColor' : "rgba(151,187,205,1)",
                  'pointColor' : "rgba(151,187,205,1)",
                  'pointStrokeColor' : "#fff",
                  'data' : [3,-1,0,4,4,-2,4,1]
                },
                {
                  'fillColor' : "clear",
                  'strokeColor' : "rgba(151,187,205,1)",
                  'pointColor' : "rgba(151,187,205,1)",
                  'pointStrokeColor' : "#fff",
                  'pointDot' : false,
                  'data' : [-3,-3,-1,-4,-4,-3,-4,-1]
                }
    ]
  }, {
    'scaleOverride' : false, 
    'bezierCurve' : true, 
    'animation' : false,
    'titleText' : 'testest'     
    });
    
  
  Line chart2 = new Line({
    'labels' : ["1","2","3","4","5","6"],
    'datasets' : [
                {
                  'fillColor' : "rgba(123,244,220,0.5)",
                  'strokeColor' : "rgba(220,220,220,1)",
                  'pointColor' : "rgba(220,220,220,1)",
                  'pointStrokeColor' : "#fff",
                  'data' : [
                            [null,20,16],
                            null,
                            [null,10,null],
                            [null,10,null],
                            24,
                            [null,17,null,25,null,20,14,null,23,25,40,20,null]
                  ]
                }
    ]

  }, {
    'animationEasing': 'easeOutElastic',
    'animation' : false,
    'bezierCurve' : true, 
    }
  );
  
  Bar bar = new Bar({
                      'labels' : ["January","February","March","April","May","June","July"],
                      'datasets' : [
                                  {
                                    'fillColor' : "rgba(220,220,220,0.5)",
                                    'strokeColor' : "rgba(220,220,220,1)",
                                    'data' : [65,59,90,81,56,55,40]
                                  },
                                  {
                                    'fillColor' : "rgba(255,255,255,1)",
                                    'strokeColor' : "rgba(0,0,255,0.5)",
                                    'data' : [28,48,40,19,null,27,100]
                                  }
                                  ]

  }, null);
  
  Bar bar2 = new Bar({
                      'labels' : ["January","February","March","April","May","June","July"],
                      'datasets' : [
                                  {
                                    'fillColor' : "rgba(220,220,220,0.5)",
                                    'strokeColor' : "rgba(220,220,220,1)",
                                    'data' : [55,59,90,59,56,55,60]
                                  }]

  }, 
  {
    'titleText' : 'testest'     
  });

  DivElement container = new DivElement();
  container.style.height ='400px';
  container.style.width =  '100%';
  document.body.children.add(container);
  chart.show(container);
  
  DivElement container2 = new DivElement();
  container2.style.height ='400px';
  container2.style.width =  '100%';
  document.body.children.add(container2);
  //chart2.show(container2);
  
  DivElement container3 = new DivElement();
  container3.style.height ='400px';
  container3.style.width =  '100%';
  document.body.children.add(container3);
  //bar.show(container3);
  
  DivElement container4 = new DivElement();
  container4.style.height ='400px';
  container4.style.width =  '100%';
  document.body.children.add(container4);
  //bar2.show(container4);


}
